[![Documentation Status](https://readthedocs.org/projects/imgms/badge/?version=latest)](https://imgms.readthedocs.io/en/latest/?badge=latest)

# imgMS
Python package for data reduction of LA-ICP-MS measurements.
